services

package
v0.1.4-0...-8b98d0b Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 24, 2025 License: GPL-3.0 Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Service

type Service interface {
	// Starts the service and blocks until it is stopped or an unrecoverable
	// error occurs.
	Run() error
	// Stops the service. Retruns error on failure to stop service. Either
	// with error or without must stop the service.
	Stop(ctx context.Context) error
}

Service describes the common methods all rat services must implement.

Jump to