Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Service ¶
type Service interface {
// Starts the service and blocks until it is stopped or an unrecoverable
// error occurs.
Run() error
// Stops the service. Retruns error on failure to stop service. Either
// with error or without must stop the service.
Stop(ctx context.Context) error
}
Service describes the common methods all rat services must implement.
Click to show internal directories.
Click to hide internal directories.